/*************************************************  Driver Functions Header  ***************************************************
	Red Rapids
	797 N. Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Description: Adapter functions that are common to all products.

	Copyright 2018, Red Rapids, Inc.

*************************************************  Driver Functions  Header ***************************************************/

#ifndef _DRIVER_H_
#define _DRIVER_H_

#if defined(__cplusplus)
    extern "C" {
#endif

// Set the number of Red Rapids devices attached to the host.
#define NUM_DEVICES			1

// Define error codes returned by API functions.
#define OK					0
#define BAD_SETTING			-500
	#define MODEL_NUMBER			BAD_SETTING - 1
	#define DAC_INTERPOLATE			BAD_SETTING - 2
	#define DAC_PLL					BAD_SETTING - 3
	#define DMA_BUFFER				BAD_SETTING - 4
	#define PHASE_BREAK				BAD_SETTING - 5
#define CONFIG_FAIL			-520
	#define CLOCK_NOSOL				CONFIG_FAIL - 1
	#define CLOCK_LOCK				CONFIG_FAIL - 2
	#define SYNTH_LOCK				CONFIG_FAIL - 3
	#define SERDES_NOSOL			CONFIG_FAIL - 4
	#define DAC_PLL_LOCK			CONFIG_FAIL - 5
	#define DAC_DLL_LOCK			CONFIG_FAIL - 6
	#define DAC_FIFO_RST			CONFIG_FAIL - 7
#define RUN_FAIL			-530
	#define TIME_OUT				RUN_FAIL - 1
	#define FLASH_ERROR				RUN_FAIL - 2
 
// Structure to store descriptor information for UIO devices (/dev/uio#) that are identified as Red Rapids hardware.
typedef struct {
	unsigned UIONumber;				// Linux UIO character device file number.
	unsigned SubSysID;				// PCI subsystem ID.
	unsigned long long BAR0Size;	// Size of the BAR0 space.
	unsigned long long BAR2Size;	// Size of the BAR2 space.
} s_UIOScan;

// Structure to store mapping information for Red Rapids UIO character devices (/dev/uio#).
typedef struct {
	int fd;							// UIO file descriptor returned by open().
	volatile unsigned long long *BAR0;		// Pointer to BAR0 register space.
	volatile unsigned long long *BAR2;		// Pointer to BAR2 register space.
} s_DEVMap;

// Structure to store buffer information retrieved from Red Rapids DMA character devices (/dev/rrdma#).
typedef struct {
	int fd;							// DMA file descriptor returned by open().
	unsigned PageNumber;			// Number of the currently mapped DMA page starting from zero.
	unsigned PageCount;				// Number of DMA pages available in the buffer.
	unsigned PagesPerMark;			// Number of DMA pages to transfer between completion marker (status) flags.
	unsigned BurstSizeB;			// Size (bytes) of each burst transaction per DMA page.
	unsigned BurstCount;			// Number of burst transactions per DMA page.
	unsigned long long *Address;	// Variable used to store both physical and virtual addresses assigned to each DMA page.
} s_DMABuf;

// Structure to store the Red Rapids device hardware handle.
typedef struct {
	unsigned DevNum;				// Device number assigned to the Red Rapids hardware (zero based).
	s_DEVMap DEV;					// UIO device structure.
	s_DMABuf *DMA;					// DMA config for all DMA buffers.
	void *User;						// Undefined pointer available to user applications.
} s_Handle;

// Prototypes for each of the driver functions.
int DEVClose(s_UIOScan UIO, s_DEVMap *p_DEV);
void DEVInit(s_Handle *p_HW, unsigned DevNum);
int DEVOpen(s_UIOScan UIO, s_DEVMap *p_DEV);
unsigned UIOScan(s_UIOScan *p_UIO);

#ifdef __cplusplus
}
#endif

#endif

