/*****************************************************  Global Functions  *****************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following functions are common to several Red Rapids applications.

	Rev History:	09-05-2018:		Initial release.

	Copyright 2018, Red Rapids, Inc.

*****************************************************  Global Functions  *****************************************************/
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <time.h>
#include <errno.h>

#include "driver_functions.h"
#include "flash.h"
#include "global_functions.h"

// Report the firmware revision date (MMDDYYYY).
// Returns the firmware revision date in hex format, but it is not a hex value (e.g. 04/27/2012 returns 0x04272012).
unsigned FirmwareRevision(s_Handle *p_HW)
{
	// Read the identification address.
	return (unsigned)(p_HW->DEV.BAR2[IDENTIFICATION] & 0x00000000FFFFFFFFull);
}

// Set a timer in units of microseconds.
// Return of zero indicates success, non-zero indicates an error condition.
int MicrosecondTimer(long uSeconds)
{
	struct timespec ts;
	
	// Convert the requested time to seconds and nanoseconds.
	ts.tv_sec = (time_t)uSeconds / 1000000;
	ts.tv_nsec = (uSeconds % 1000000) * 1000;
	
	// Sleep the requested duration.
	if (nanosleep(&ts, NULL) < 0)
		return errno;
	
	return OK;
}

// Report the model number of the device.
// Returns the model number in hex format, but it is not a hex value (e.g. Model 266 returns 0x266).
unsigned ModelNumber(s_Handle *p_HW)
{
	// Read the identification address.
	return (unsigned)((p_HW->DEV.BAR2[IDENTIFICATION] >> 32) & 0x0000000000000FFFull);
}

// Issue a software reset that is equivalent to a power-on reset.
void SoftwareReset(s_Handle *p_HW)
{
	// Write to the software reset address.
	p_HW->DEV.BAR0[SOFTWARE_RESET] = 0x0ull;
}
