/*************************************************  Global Functions Header  ***************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Copyright 2018, Red Rapids, Inc.

*************************************************  Global Functions Header  ***************************************************/

#ifndef _GLOBAL_FUNCTIONS_H_
#define _GLOBAL_FUNCTIONS_H_

#if defined(__cplusplus)
	extern "C" {
#endif


// Structure to store the LED on/off control settings.
typedef struct
{
	unsigned LEDA;
	unsigned LEDB;
} s_LEDControl;

// Structure to store GPIO and USER signal translator directions.
typedef struct
{
	unsigned GPIODirection[6];
	unsigned USERDirection[62];
} s_PinDirection;

// Structure to store the results returned by an error status query to the device.
typedef struct
{
	unsigned Bar[4];
	unsigned Clock[8];
} s_ErrorStatus;

// Structure to store the results returned by an interrupt status query to the device.
typedef struct
{
	unsigned Channel[8];
	unsigned Error;
} s_GlobalStatus;

// Structure to store temperature results measured on the device.
typedef struct
{
	double Sensor[5];
	double Vcc;
} s_Temperature;

// Structure to store power results measured on the device.
typedef struct
{
	double Supply1[3];
	double Supply2[3];
	double Supply3[3];
} s_Power;

// Prototypes for each of the global functions in alphabetic order.
unsigned ChannelCount(s_Handle *p_HW, unsigned RxTxSelect);
int ClockInit(s_Handle *p_HW);
int ClockInitLMK01000(s_Handle *p_HW, unsigned CLKout0, unsigned CLKout4, unsigned CLKout5);
int ClockStatus(s_Handle *p_HW, unsigned ChipSelect);
void ErrorMask(s_Handle *p_HW, s_ErrorStatus ErrorIntMask);
unsigned FirmwareRevision(s_Handle *p_HW);
unsigned GetClockFrequency(s_Handle *p_HW);
int GetErrorStatus(s_Handle *p_HW, s_ErrorStatus *p_ErrorStatus);
int GetGlobalStatus(s_Handle *p_HW, s_GlobalStatus *p_GlobalStatus);
double GetPower(s_Handle *p_HW, s_Power *p_Power);
void GetTemperature(s_Handle *p_HW, s_Temperature *p_Temperature);
void GPIOConnect(s_Handle *p_HW);
void GPIODisconnect(s_Handle *p_HW);
void InterruptMask(s_Handle *p_HW, unsigned GlobalIntMask);
void LoadPinDirection(s_Handle *p_HW, s_PinDirection Translator);
int MicrosecondTimer(long uSeconds);
unsigned ModelNumber(s_Handle *p_HW);
int SerDesInit(s_Handle *p_HW);
void Serial(s_Handle *p_HW, unsigned BusSelect, unsigned MultiFunction, unsigned Instruction, unsigned AddressSize, unsigned Data, unsigned DataSize, unsigned *p_ReadValue);
void SoftwareReset(s_Handle *p_HW);
void SoftwareTrigger(s_Handle *p_HW);
void USERConnect(s_Handle *p_HW);
void USERDisconnect(s_Handle *p_HW);

#ifdef __cplusplus
}
#endif

#endif
