/****************************************************  Operating Defaults  *****************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following defaults are assigned to structures that configure operating variables of the FPGA reference design.

	Rev History:  08-08-2018:	Inital release.

	Copyright 2018, Red Rapids, Inc.

****************************************************  Operating Defaults  *****************************************************/

#include "driver_functions.h"
#include "sigfpga.h"
#include "global_functions.h"
#include "channel_functions.h"

#if defined(__cplusplus)
	extern "C" {
#endif

//////////////////////////////////  Configure Transmitter & Receiver Channel Synchronizers  //////////////////////////////////

// Initialize a default structure for all channels.
s_Synchronizer SynchronizerDefault = {
	1,	// StartEvent					Event that will activate the channel. - Range: 0 (none/immediate), 1 (software trigger), 2 (hardware trigger)
	3,	// StopEvent					Event that will deactivate the channel. - Range: 0 (flow control), 1 (software trigger), 2 (hardware trigger), 3 (sample count)
	8192	// SampleCount				Number of samples to collect when sample count is selected for the synchronizer StartEvent. - Range: 0 to (2^32 - 1) in multiples of 8 bytes
};

///////////////////////////////////////////////////  Configure Interrupts  ////////////////////////////////////////////////////

// Initialize a default variable for the global interrupt mask setting.
unsigned long GlobalMaskDefault = 0;	// Global Interrupt Mask 	Enable or disable all interrupt generation from the device. - Range: 0 (disable) to 1 (enable)

// Initialize a default structure for the fault interrupt mask.
s_ErrorStatus ErrorMaskDefault = {
	{ // BAR Error
		0,	// BAR0 Write Error			Generate an interrupt when a BAR0 write error is detected. - Range: 0 (disable) to 1 (enable)
		0,	// BAR0 Read Error			Generate an interrupt when a BAR0 read error is detected. - Range: 0 (disable) to 1 (enable)
		0,	// BAR2 Write Error			Generate an interrupt when a BAR2 write error is detected. - Range: 0 (disable) to 1 (enable)
		0	// BAR2 Read Error			Generate an interrupt when a BAR2 read error is detected. - Range: 0 (disable) to 1 (enable)
	},
	{ // Clock
		0,	// DCM Lock					Generate an interrupt when the FPGA DCM is out of lock. - Range: 0 (disable) to 1 (enable)
		0,	// IDELAY Lock				Generate an interrupt when the FPGA IDELAY controller is out of lock. - Range: 0 (disable) to 1 (enable)
		0	// Clock Lock				Generate an interrupt when the clock lock function produces an error. - Range: 0 (disable) to 1 (enable)
	}
};

// Initialize a default structure for the channel status interrupt mask.
s_ChannelIntMask ChannelMaskDefault = {
	1,	// DMA Marker						Generate an interrupt when the DMA marker is detected. - Range: 0 (disable) to 1 (enable)
	{ // Error
		0,	// Converter (ADC/DAC) Error	Generate an interrupt when a converter (ADC/DAC) error is detected. - Range: 0 (disable) to 1 (enable)
		0	// FIFO Error					Generate an interrupt when a FIFO error is detected. - Range: 0 (disable) to 1 (enable)
	}
};

#ifdef __cplusplus
}
#endif
